@@ -25,7 +25,7 @@ class CodeInjector:
         """Evaluate expression within namespaces of class."""
         # pylint: disable=eval-used
         try:
-            result = eval(expression, self.f_globals, self.namespace)
+            result = eval(expression, self.f_globals)
         except TypeError:
             # typeerror: e.g. Optional[int]
             result = object()
