@@ -59,6 +59,9 @@ class BitFields(
         pieces: List[bytes],
         dump: Optional[Record] = None,
     ) -> None:
+        if isinstance(value, dict):
+            value = cls(**value)
+
         if dump is None:
             pieces.append(
                 int(value).to_bytes(cls.__nbytes__, cls.__byteorder__, signed=False)
@@ -128,6 +131,9 @@ class BitFields(
 
     @classmethod
     def _normalize_for_compare(cls, value, other):
+        if isinstance(other, dict):
+            other = cls(**other)
+
         if isinstance(other, cls):
             other = other.__value__ & cls.__compare_mask__
             value = value & cls.__compare_mask__
