@@ -180,6 +180,10 @@ class TestEquality:
         assert ForCompare(f1=1, f2=2, f3=2) == ForCompare(f1=1, f2=2, f3=3)
         assert not ForCompare(f1=0, f2=2, f3=2) == ForCompare(f1=1, f2=2, f3=2)
 
+    def test_dict(self):
+        """Verify support for other being a dict."""
+        assert ForCompare(f1=1, f2=2, f3=2) == dict(f1=1, f2=2, f3=2)
+
 
 class TestCompares:
 
