@@ -142,6 +142,9 @@ class TestFirst(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_m1, m_m2, m_m3, m_m4) = value
 
                 if dump is None:
@@ -214,9 +217,15 @@ class TestFirst(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -347,6 +356,9 @@ class TestLast(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_m0, m_m1, m_m2, m_m3) = value
 
                 if dump is None:
@@ -417,9 +429,15 @@ class TestLast(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -629,6 +647,9 @@ class TestMultiple(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_m0, m_m1, m_m2, m_m3, m_m4, m_m5, m_m6, m_m7) = value
 
                 if dump is None:
@@ -771,9 +792,15 @@ class TestMultiple(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -914,6 +941,9 @@ class TestArtificialSplit(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_m1, m_m2, m_m3, m_m4) = value
 
                 if dump is None:
@@ -1000,9 +1030,15 @@ class TestArtificialSplit(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
