@@ -156,6 +156,9 @@ class TestSimpleSingleDim(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_data_len, m_data, m_bookend) = value
 
                 if dump is None:
@@ -200,9 +203,15 @@ class TestSimpleSingleDim(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -344,6 +353,9 @@ class TestTypeFactorySingleDim(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_data_type, m_data_len, m_data, m_bookend) = value
 
                 if dump is None:
@@ -410,7 +422,9 @@ class TestTypeFactorySingleDim(Case):
                 return structure, offset
 
             def __eq__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_data_type, _s_data_len, _s_data, _s_bookend = self
                     if _s_data_len is None:
                         _s_data_type, _s_data_len, _s_data, _s_bookend = self.unpack(self.ipack())
@@ -422,7 +436,9 @@ class TestTypeFactorySingleDim(Case):
                     return list.__eq__(self, other)
 
             def __ne__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_data_type, _s_data_len, _s_data, _s_bookend = self
                     if _s_data_len is None:
                         _s_data_type, _s_data_len, _s_data, _s_bookend = self.unpack(self.ipack())
@@ -588,6 +604,9 @@ class TestTypeFactoryMultiDim(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_data_type, m_data_dims, m_data, m_bookend) = value
 
                 if dump is None:
@@ -654,7 +673,9 @@ class TestTypeFactoryMultiDim(Case):
                 return structure, offset
 
             def __eq__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_data_type, _s_data_dims, _s_data, _s_bookend = self
                     if _s_data_dims is None:
                         _s_data_type, _s_data_dims, _s_data, _s_bookend = self.unpack(self.ipack())
@@ -666,7 +687,9 @@ class TestTypeFactoryMultiDim(Case):
                     return list.__eq__(self, other)
 
             def __ne__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_data_type, _s_data_dims, _s_data, _s_bookend = self
                     if _s_data_dims is None:
                         _s_data_type, _s_data_dims, _s_data, _s_bookend = self.unpack(self.ipack())
