@@ -127,6 +127,9 @@ class TestSimple(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_size, m_string, m_bookend) = value
 
                 if dump is None:
@@ -207,7 +210,9 @@ class TestSimple(Case):
                 return structure, offset
 
             def __eq__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_size, _s_string, _s_bookend = self
                     if _s_size is None:
                         _s_size, _s_string, _s_bookend = self.unpack(self.ipack())
@@ -219,7 +224,9 @@ class TestSimple(Case):
                     return list.__eq__(self, other)
 
             def __ne__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_size, _s_string, _s_bookend = self
                     if _s_size is None:
                         _s_size, _s_string, _s_bookend = self.unpack(self.ipack())
@@ -453,6 +460,9 @@ class TestRatio(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_size, m_string, m_bookend) = value
 
                 if dump is None:
@@ -535,7 +545,9 @@ class TestRatio(Case):
                 return structure, offset
 
             def __eq__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_size, _s_string, _s_bookend = self
                     if _s_size is None:
                         _s_size, _s_string, _s_bookend = self.unpack(self.ipack())
@@ -547,7 +559,9 @@ class TestRatio(Case):
                     return list.__eq__(self, other)
 
             def __ne__(self, other: Any) -> bool:
-                if isinstance(other, type(self)):
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                elif isinstance(other, type(self)):
                     _s_size, _s_string, _s_bookend = self
                     if _s_size is None:
                         _s_size, _s_string, _s_bookend = self.unpack(self.ipack())
@@ -829,6 +843,9 @@ class TestNoCompute(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_size, m_string, m_bookend) = value
 
                 if dump is None:
@@ -885,9 +902,15 @@ class TestNoCompute(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
